###############################################################################
#
#   MarathUp - Light Properties Dialog
#
###############################################################################

require "Marathon/PropertyUtils.rb"

module Marathon

	#----------------------------------------------------------------------------------
	
	class AttrTable < UnlabelledAttr
	
		def initialize(rows)
			@rows = rows
		end
		
		def control_html(dict, prefix, mixed)
			leader = '<table>'
			header = []
			header.push('<td></td>')
			for col in @rows[0].columns
				header.push('<td>' + col.title + '</td>')
				col.show_title = false
			end
			rows = []
			rows.push('<tr valign="bottom">' + header.join() + '</tr>')
			for row in @rows
				rows.push('<tr>' + row.html(dict, prefix, mixed) + '</tr>')
			end
			trailer = '</table>'
			return leader + rows.join("\n") + trailer
		end
		
		def get_values(dlog, dict, prefix, mixed)
			for row in @rows
				row.get_values(dlog, dict, prefix, mixed)
			end
		end

	end # class AttrTable

	#----------------------------------------------------------------------------------
	
	class AttrRow < DialogAttr
	
		attr :columns
	
		def initialize(name, title, columns)
			super(name, title)
			@columns = columns
		end
			
		def html(dict, prefix, mixed)
			id = self.element_id(prefix)
			cols = []
			cols.push('<td>' + @title + '</td>')
			for attr in @columns
				ctrl = attr.control_html(dict, id, mixed)
				cols.push('<td>' + ctrl + '</td>')
			end
			return cols.join("\n")
		end
		
		def get_values(dlog, dict, prefix, mixed)
			id = self.element_id(prefix)
			for attr in @columns
				attr.get_values(dlog, dict, id, mixed)
			end
		end

	end # class AttrRow

	#----------------------------------------------------------------------------------
	
	LightFunctions = [
		"Constant",
		"Linear",
		"Smooth",
		"Flicker",
	]

	LightTypes = [
		"Normal",
		"Strobe",
		"Media",
	]
	
	LightFlags = [
		[0x1, "Initially active"],
		[0x2, "Slaved intensities"],
		[0x4, "Stateless"],
	]

	LightFuncAttrs = [
		EnumAttr.new("function", "Function", LightFunctions),
		IntAttr.new("period", "Period"),
		IntAttr.new("delta_period", "Delta<br>Period"),
		FloatAttr.new("intensity", "Intensity"),
		FloatAttr.new("delta_intensity", "Delta<br>Intensity"),
	]
	
	LightDialog = DialogDefinition.new("Light Properties", 550, 500, [
		StrAttr.new("name", "Name"),
		StrAttr.new("tag", "Tag"),
		EnumAttr.new("type", "Type", LightTypes),
		FlagsAttr.new("flags", 1, LightFlags),
		IntAttr.new("phase", "Phase"),
		AttrTable.new([
			AttrRow.new("becoming_active", "Becoming Active", LightFuncAttrs),
			AttrRow.new("primary_active", "Primary Active", LightFuncAttrs),
			AttrRow.new("secondary_active", "Secondary Active", LightFuncAttrs),
			AttrRow.new("becoming_inactive", "Becoming Inactive", LightFuncAttrs),
			AttrRow.new("primary_inactive", "Primary Inactive", LightFuncAttrs),
			AttrRow.new("secondary_inactive", "Secondary Inactive", LightFuncAttrs),
		]),
	])
	
	#----------------------------------------------------------------------------------
	
end # module Marathon
