###############################################################################
#
#   MarathUp - Object Properties Dialogs
#
###############################################################################

require "Marathon/PropertyUtils.rb"
require "Marathon/EditSound.rb"

module Marathon

	#----------------------------------------------------------------------------------

	MonsterActivations = [
		"By player",
		"By nearest hostile",
		"By goal",
		"Randomly",
	]
	
	MonsterFlags = [
		[0x04, "Blind"],
		[0x08, "Deaf"],
		[0x01, "Teleports in"],
		[0x10, "Teleports out"],
		[0x02, "Hangs from ceiling"],
	]

	MonsterDialog = DialogDefinition.new("Monster Properties", 300, 200, [
		EnumAttr.new("activation", "Activated", MonsterActivations),
		FlagsAttr.new("flags", 1, MonsterFlags),
	])
	
	#----------------------------------------------------------------------------------

	SceneryFlags = [
		[0x02, "Hangs from ceiling"],
	]
	
	SceneryDialog	= DialogDefinition.new("Scenery Properties", 300, 200, [
		FlagsAttr.new("flags", 1, SceneryFlags),
	])
	
	#----------------------------------------------------------------------------------

	ItemFlags = [
		[0x01, "Teleports in"],
		[0x02, "Hangs from ceiling"],
		[0x20, "Network only"],
	]
	
	ItemDialog	= DialogDefinition.new("Item Properties", 300, 200, [
		FlagsAttr.new("flags", 1, ItemFlags),
	])
	
	#----------------------------------------------------------------------------------

	PlayerTeams = [
		[0x01, "Violet team"],
		[0x02, "Red team"],
		[0x04, "Tan team"],
		[0x08, "Light blue team"],
		[0x10, "Yellow team"],
		[0x20, "Brown team"],
		[0x40, "Blue team"],
		[0x80, "Green team"],
	]
	
	PlayerFlags = [
		[0x02, "Hangs from ceiling"],
	]

	PlayerDialog = DialogDefinition.new("Player Properties", 300, 200, [
		FlagsAttr.new("index", 2, PlayerTeams),
		FlagsAttr.new("flags", 1, PlayerFlags),
	])
	
	#----------------------------------------------------------------------------------

	GoalDialog = DialogDefinition.new("Goal Properties", 300, 200, [
		StrAttr.new("name", "Name"),
	])
	
	#----------------------------------------------------------------------------------

	SoundVolumeModes = [
		"Fixed (0.0 - 1.0)",
		"Controlled by light",
	]
	
	SoundFlags = [
		[0x1, "Platform sound"],
	]
	
	SoundDialog = DialogDefinition.new("Sound Properties", 300, 200, [
		EnumAttr.new("index", "Type", SoundTypes),
		EnumAttr.new("volume_mode", "Volume mode", SoundVolumeModes),
		StrAttr.new("volume", "Volume"),
		FlagsAttr.new("flags", 1, SoundFlags),
	])
	
	#----------------------------------------------------------------------------------

	NoteDialog = DialogDefinition.new("Note Properties", 420, 120, [
		StrAttr.new("text", "Text", 50),
	])
	
	#----------------------------------------------------------------------------------

	ObjectDialogs = {
		"*Monster" => [MonsterDialog, "object"],
		"*Scenery" => [SceneryDialog, "object"],
		"*Item" => [ItemDialog, "object"],
		"*Player" => [PlayerDialog, "object"],
		"*Goal" => [GoalDialog, "object"],
		"*Sound" => [SoundDialog, "object"],
		"*Light" => [LightDialog, "light"],
		"*Liquid" => [MediaDialog, "media"],
		"*AmbientSound" => [AmbientSoundDialog, "ambient_sound"],
		"*RandomSound" => [RandomSoundDialog, "random_sound"],
		"*Note" => [NoteDialog, "note"],
	}

#	def Marathon.edit_object()
#		catch :Abort do
#			obj = get_selected_group_or_instance()
#			if obj.is_a?(Sketchup::Group)
#				edit_parameters(obj)
#			else
#				group = object_group(obj)
#				if not group
#					edit_parameters(obj)
#				else
#					dlog, key = ObjectDialogs[group]
#					if dlog
#						attrs = get_attributes(obj, key, true)
#						attrs["name"] = obj.name
#						dlog.edit(attrs) {
#							obj.name = attrs["name"]
#						}
#					else
#						abort("Object has no editable Marathon properties.")
#					end
#				end
#			end
#		end
#	end

	def Marathon.edit_object()
		catch :Abort do
			kind, objects = get_selected_groups_and_instances()
			if kind == nil
				if objects.length > 1
					abort("Parameters can be edited for only one object at a time.")
				end
				edit_parameters(objects[0])
			else
				dlog, key = ObjectDialogs[kind]
				if dlog
					dlog.edit_entities(objects, key, named = true)
				else
					abort("Object has no editable Marathon properties.")
				end
			end
		end
	end

	#----------------------------------------------------------------------------------

end # module Marathon
		
if not $marathon_edit_object
	menu = marathon_submenu()
	menu.add_item("Object Properties") {Marathon.edit_object()}
	$marathon_edit_object = true
end
