###############################################################################
#
#   MarathUp - Object Placement Dialogs
#
###############################################################################

require "Marathon/PropertyUtils.rb"

module Marathon

	#----------------------------------------------------------------------------------

	MonsterTypes = [ # TODO: Load from file
		"Tick, energy",
		"Tick, oxygen",
		"Tick, kamikazi",
		"Compiler, minor",
		"Compiler. major",
		"Compiler, minor, invisible",
		"Compiler, major, invisible",
		"Fighter, minor",
		"Fighter, major",
		"Fighter, projectile,  minor",
		"Fighter, projectile, major",
		"Civilian, crew",
		"Civilian, science",
		"Civilian, security",
		"Civilian, assimilated",
		"Hummer, minor",
		"Hummer, major",
		"Hummer, big, minor",
		"Hummer, big, major",
		"Hummer, possessed",
		"Cyborg, minor",
		"Cyborg, major",
		"Cyborg, flame, minor",
		"Cyborg, flame, major",
		"Enforcer, minor",
		"Enforcer, major",
		"Hunter, minor",
		"Hunter, major",
		"Trooper, minor",
		"Trooper, major",
		"Mother of all cyborgs",
		"Mother of all hunters",
		"Yeti, sewage",
		"Yeti, water",
		"Yeti, lava",
		"Defender, minor",
		"Defender, major",
		"Juggernaut, minor",
		"Juggernaut, major",
		"Tiny fighter",
		"Tiny bob",
		"Tiny yeti",
	]
	
	ItemTypes = [ # TODO: Load from file
		"Magnum pistol",
		"Magnum magazine",
		"Fusion pistol",
		"Fusion battery",
		"Assault rifle",
		"Assault rifle magazine",
		"Assault rifle grenades",
		"Missile launcher",
		"Missile launcher magazine",
		"Invisibility powerup",
		"Invincibility powerup",
		"Infravision powerup",
		"Alien weapon",
		"Alien weapon magazine",
		"Flamethrower",
		"Flamethrower canister",
		"Extravision powerup",
		"Oxygen recharge",
		"Energy recharge",
		"Double energy recharge",
		"Triple energy recharge",
		"Shotgun",
		"Shotgun magazine",
		"S'pht_door_key,",
		"Uplink chip",
		"Light blue ball",
		"Red ball",
		"Violet ball",
		"Yellow ball",
		"Brown ball",
		"Orange ball",
		"Blue ball",
		"Green ball",
		"Sub-machine gun",
		"Sub-machine gun clip",
	]
	
	PlacementRowAttrs = [
		IntAttr.new("ini", "Initial"),
		IntAttr.new("min", "Min"),
		IntAttr.new("max", "Max"),
		IntAttr.new("tot", "Total"),
		IntAttr.new("app", "Appear<br>Percent"),
		BoolAttr.new("inf", "Infinite<br>Supply"),
		BoolAttr.new("rnd", "Random<br>Location"),
	]

	#----------------------------------------------------------------------------------

	def Marathon.placement_dialog(title, width, height, row_titles)
		rows = []
		for i in 0...row_titles.length
			prefix = (i+1).to_s()
			rows.push(AttrRow.new(prefix, row_titles[i], PlacementRowAttrs))
		end
		table = AttrTable.new(rows)
		dlog = DialogDefinition.new(title, width, height, [table], true)
		return dlog
	end

	def Marathon.edit_placement(attrs, title, row_titles)
		dlog = placement_dialog(title, 600, 500, row_titles)
		dlog.edit(attrs)
	end
	
	def Marathon.edit_monster_placement()
		attrs = get_monster_placement_attributes(true)
		edit_placement(attrs, "Monster Placement", MonsterTypes)
	end
	
	def Marathon.edit_item_placement()
		attrs = get_item_placement_attributes(true)
		edit_placement(attrs, "Item Placement", ItemTypes)
	end

	#----------------------------------------------------------------------------------

end # module Marathon

if not $marathon_edit_monster_placement
	menu = marathon_submenu()
	menu.add_item("Monster Placement") {Marathon.edit_monster_placement()}
	$marathon_edit_monster_placement = true
end

if not $marathon_edit_item_placement
	menu = marathon_submenu()
	menu.add_item("Item Placement") {Marathon.edit_item_placement()}
	$marathon_edit_item_placement = true
end
