###############################################################################
#
#   MarathUp - Wall, Floor and Ceiling Properties Dialogs
#
###############################################################################

require "Marathon/PropertyUtils.rb"

module Marathon

	#----------------------------------------------------------------------------------

	LineFlags = [
		[0x4000, "Solid"],
		[0x2000, "Opaque"], # Prevent TRANSPARENT_LINE_BIT from being set
	]

	SideFlags = [
		[0x0001, "Initially on"],
		#[0x0002, "Control panel"], # Set automatically
		[0x0004, "Repair switch"],
		[0x0008, "Uses an item"],
		[0x0010, "Only active when lit"],
		[0x0020, "Can be destroyed"],
		[0x0040, "Only activated by projectiles"],
	]

	ControlPanelDefinitions = [
		["(1) Oxygen recharge",      ''],
		["(1) Shield recharge 1x",   ''],
		["(1) Shield recharge 2x",   ''],
		["(1) Chip insertion",       'tag'],
		["(1) Light switch",         'light'],
		["(1) Platform switch",      'platform'],
		["(1) Tag switch",           'tag'],
		["(1) Pattern buffer",       ''],
		["(1) Computer terminal",    'terminal'],
		["(1) Breakable tag switch", 'tag'],

		["(2) Shield recharge 1x",   ''],
		["(2) Shield recharge 2x",   ''],
		["(2) Shield recharge 3x",   ''],
		["(2) Light switch",         'light'],
		["(2) Platform switch",      'platform'],
		["(2) Tag switch",           'tag'],
		["(2) Pattern buffer",       ''],
		["(2) Computer terminal",    'terminal'],
		["(2) Oxygen recharge",      ''],
		["(2) Chip tag switch",      'tag'],
		["(2) Breakable tag switch", 'tag'],

		["(3) Shield recharge 1x",   ''],
		["(3) Shield recharge 2x",   ''],
		["(3) Shield recharge 3x",   ''],
		["(3) Light switch",         'light'],
		["(3) Platform switch",      'platform'],
		["(3) Tag switch",           'tag'],
		["(3) Pattern buffer",       ''],
		["(3) Computer terminal",    'terminal'],
		["(3) Oxygen recharge",      ''],
		["(3) Chip tag switch",      'tag'],
		["(3) Breakable tag switch", 'tag'],

		["(5) Shield recharge 1x",   ''],
		["(5) Shield recharge 2x",   ''],
		["(5) Shield recharge 3x",   ''],
		["(5) Light switch",         'light'],
		["(5) Platform switch",      'platform'],
		["(5) Tag switch",           'tag'],
		["(5) Pattern buffer",       ''],
		["(5) Computer terminal",    'terminal'],
		["(5) Oxygen recharge",      ''],
		["(5) Chip tag switch",      'tag'],
		["(5) Breakable tag switch", 'tag'],

		["(4) Shield recharge 1x",   ''],
		["(4) Shield recharge 2x",   ''],
		["(4) Shield recharge 3x",   ''],
		["(4) Light switch",         'light'],
		["(4) Platform switch",      'platform'],
		["(4) Tag switch",           'tag'],
		["(4) Pattern buffer",       ''],
		["(4) Computer terminal",    'terminal'],
		["(4) Oxygen recharge",      ''],
		["(4) Chip tag switch",      'tag'],
		["(4) Breakable tag switch", 'tag'],
	]
	
	ControlPanelTypes = ["None"] + ControlPanelDefinitions.map{|x| x[0]}
	
	#----------------------------------------------------------------------------------

	WallDialog = DialogDefinition.new("Wall Properties", 350, 400, [
		FlagsAttr.new("line_flags", 1, LineFlags),
		EnumAttr.new("transfer_mode", "Transfer Mode", TransferModes),
		StrAttr.new("light", "Light Source"),
		HRule,
		EnumAttr.new("control_panel_type", "Control Panel", ControlPanelTypes, true),
		StrAttr.new("control_panel_permutation", "Permutation"),
		FlagsAttr.new("side_flags", 1, SideFlags),
	])
	
#	def Marathon.edit_wall()
#		catch :Abort do
#			face = get_selected_wall_face()
#			attrs = get_wall_attributes(face, true)
#			WallDialog.edit(attrs)
#		end
#	end
	
	def Marathon.edit_wall()
		catch :Abort do
			faces = get_selected_wall_faces()
			WallDialog.edit_entities(faces, SideAttrs)
		end
	end

	#----------------------------------------------------------------------------------

	FloorCeilingDialog = DialogDefinition.new("Floor/Ceiling Properties", 300, 200, [
		StrAttr.new("light", "Light source"),
		EnumAttr.new("transfer_mode", "Transfer mode", TransferModes),
		BoolAttr.new("align_texture", "Use Sketchup texture alignment"),
	])
	
#	def Marathon.edit_floor_or_ceiling()
#		catch :Abort do
#			face = get_selected_floor_or_ceiling_face()
#			attrs = get_floor_ceiling_attributes(face, true)
#			FloorCeilingDialog.edit(attrs)
#		end
#	end

	def Marathon.edit_floor_or_ceiling()
		catch :Abort do
			faces = get_selected_floor_or_ceiling_faces()
			FloorCeilingDialog.edit_entities(faces, FloorCeilingAttrs)
		end
	end

	#----------------------------------------------------------------------------------

end # module Marathon
		
if not $marathon_edit_wall
	menu = marathon_submenu()
	menu.add_item("Wall Properties") {Marathon.edit_wall()}
	$marathon_edit_wall = true
end

if not $marathon_edit_floor_ceiling
	menu = marathon_submenu()
	menu.add_item("Floor/Ceiling Properties") {Marathon.edit_floor_or_ceiling()}
	$marathon_edit_floor_ceiling = true
end
